pub struct GroupMemberCandidate {
pub service_id: ServiceId,
pub credential: Option<ExpiringProfileKeyCredential>,
}Expand description
A candidate member for group creation/modification.
If credential is Some, member will be added with a presentation. If credential is None, member will be added as pending (invite).
Fields
service_id: ServiceIdcredential: Option<ExpiringProfileKeyCredential>Trait Implementations
Sourceimpl Clone for GroupMemberCandidate
impl Clone for GroupMemberCandidate
Sourcefn clone(&self) -> GroupMemberCandidate
fn clone(&self) -> GroupMemberCandidate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for GroupMemberCandidate
impl RefUnwindSafe for GroupMemberCandidate
impl Send for GroupMemberCandidate
impl Sync for GroupMemberCandidate
impl Unpin for GroupMemberCandidate
impl UnwindSafe for GroupMemberCandidate